@@ -31,7 +31,8 @@ THE SOFTWARE.
 
 namespace Ogre {
 
-    const String MOT_FRUSTRUM = "Frustum";
+    const String MOT_FRUSTUM = "Frustum";
+    const String MOT_FRUSTRUM = MOT_FRUSTUM;
     const Real Frustum::INFINITE_FAR_PLANE_ADJUST = 0.00001;
     //-----------------------------------------------------------------------
     Frustum::Frustum(const String& name) : 
@@ -90,32 +91,20 @@ namespace Ogre {
 
 
     //-----------------------------------------------------------------------
-    void Frustum::setFarClipDistance(Real farPlane)
+    void Frustum::setFarClipDistance(float farPlane)
     {
         mFarDist = farPlane;
         invalidateFrustum();
     }
 
     //-----------------------------------------------------------------------
-    Real Frustum::getFarClipDistance(void) const
-    {
-        return mFarDist;
-    }
-
-    //-----------------------------------------------------------------------
-    void Frustum::setNearClipDistance(Real nearPlane)
+    void Frustum::setNearClipDistance(float nearPlane)
     {
         OgreAssert(nearPlane > 0, "Invalid clip distance");
         mNearDist = nearPlane;
         invalidateFrustum();
     }
 
-    //-----------------------------------------------------------------------
-    Real Frustum::getNearClipDistance(void) const
-    {
-        return mNearDist;
-    }
-
     //---------------------------------------------------------------------
     void Frustum::setFrustumOffset(const Vector2& offset)
     {
@@ -734,7 +723,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     const String& Frustum::getMovableType(void) const
     {
-        return MOT_FRUSTRUM;
+        return MOT_FRUSTUM;
     }
     //-----------------------------------------------------------------------
     Real Frustum::getBoundingRadius(void) const
