@@ -143,8 +143,7 @@ namespace Ogre {
             mSliceTRT.reserve(mDepth);
             for(uint32 zoffset=0; zoffset<mDepth; ++zoffset)
             {
-                String name;
-                name = "rtt/" + StringConverter::toString((size_t)this) + "/" + parent->getName();
+                String name = getNameForRenderTexture(parent->getName());
                 GLSurfaceDesc surface;
                 surface.buffer = this;
                 surface.zoffset = zoffset;
