@@ -220,7 +220,9 @@ bool Sample_ShaderSystem::frameRenderingQueued( const FrameEvent& evt )
 //-----------------------------------------------------------------------
 void Sample_ShaderSystem::setupContent()
 {
-    
+    mTextureAtlasFactory = OGRE_NEW TextureAtlasSamplerFactory;
+    mShaderGenerator->addSubRenderStateFactory(mTextureAtlasFactory);
+
     // Setup default effects values.
     mCurLightingModel       = SSLM_PerPixelLighting;
     mPerPixelFogEnable      = false;
@@ -895,14 +897,6 @@ void Sample_ShaderSystem::applyShadowType(int menuIndex)
         mTrayMgr->removeWidgetFromTray(mDirLightCheckBox);
         mDirLightCheckBox->hide();
 
-        // Disable fog on the caster pass.
-        MaterialPtr passCaterMaterial = MaterialManager::getSingleton().getByName("PSSM/shadow_caster");
-        Pass* pssmCasterPass = passCaterMaterial->getTechnique(0)->getPass(0);
-        pssmCasterPass->setFog(true);
-
-        // Set up caster material - this is just a standard depth/shadow map caster
-        mSceneMgr->setShadowTextureCasterMaterial(passCaterMaterial);
-
         // shadow camera setup
         PSSMShadowCameraSetup* pssmSetup = new PSSMShadowCameraSetup();
         pssmSetup->calculateSplitPoints(3, mCamera->getNearClipDistance(), mSceneMgr->getShadowFarDistance());
@@ -934,13 +928,6 @@ void Sample_ShaderSystem::testCapabilities( const RenderSystemCapabilities* caps
     OGRE_EXCEPT(Exception::ERR_NOT_IMPLEMENTED, "RTSS not supported on your system");
 }
 
-//-----------------------------------------------------------------------
-void Sample_ShaderSystem::loadResources()
-{
-    mTextureAtlasFactory = OGRE_NEW TextureAtlasSamplerFactory;
-    mShaderGenerator->addSubRenderStateFactory(mTextureAtlasFactory);
-}
-
 //-----------------------------------------------------------------------
 void Sample_ShaderSystem::unloadResources()
 {
